@@ -34,8 +34,6 @@ from edukit_sdk.edukit.learning.impl.learning_report_request import \
     LearningReportRequest
 from edukit_sdk.edukit.learning.model.series_course_learning_info import \
     SeriesCourseLearningInfo
-from edukit_sdk.edukit.learning.model.unitary_course_learning_info import \
-    UnitaryCourseLearningInfo
 from edukit_sdk.edukit.lesson.impl.lesson_create_request import \
     LessonCreateRequest
 from edukit_sdk.edukit.lesson.impl.lesson_delete_request import \
@@ -117,13 +115,6 @@ class EduKitImpl:
                                                    package,
                                                    self.credential_list)
 
-    # 上报用户单体课学习信息
-    def get_report_unitary_course_learning(self, user_id, course_id,
-                                           user_id_type,
-                                           unitary: UnitaryCourseLearningInfo):
-        return LearningReportRequest.report_unitary_course_learning(
-            user_id, course_id, user_id_type, unitary, self.credential_list)
-
     # 上报用户系列课学习信息
     def get_report_series_course_learning(self, user_id, course_id,
                                           user_id_type, lesson_id,
