@@ -12,25 +12,6 @@ from edukit_sdk.edukit.learning.model.user_info import UserInfo
 
 
 class LearningReportRequest:
-    @staticmethod
-    def report_unitary_course_learning(
-            user_id,
-            course_id,
-            user_id_type,
-            unitary_course_learning_info,
-            credential_list):
-        response = Response()
-        if Helpers.has_empty_param(
-                [user_id, course_id, user_id_type,
-                 unitary_course_learning_info]):
-            response.result = Helpers.build_error_result(
-                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
-            return response
-        learning_handler = LearningHandler(
-            EduKitRequestSender(credential_list))
-        return learning_handler.report_unitary_course_learning(
-            user_id, course_id, user_id_type, unitary_course_learning_info)
-
     @staticmethod
     def report_series_course_learning(user_info: UserInfo, course_id,
                                       lesson_id,
