@@ -8,27 +8,8 @@ from edukit_sdk.edukit.common.helpers.helpers import Helpers
 
 class TeacherMetaData:
     def __init__(self):
-        self._famous_flag = None
         self._default_lang = None
 
-    @property
-    def famous_flag(self):
-        """
-        :return: mixed
-        """
-        return self._famous_flag
-
-    @famous_flag.setter
-    def famous_flag(self, famous_flag):
-        """
-        该教师是否为名师，说明如下：
-        教育中心App有名师专区栏目，将教师标识为名师将有可能在该栏目中出现
-        此字段在教师信息首次提交审核时必须指定；后续更新时可不携带，此时将保持当前取值不变
-        :param famous_flag:
-        :return:
-        """
-        self._famous_flag = famous_flag
-
     @property
     def default_lang(self):
         """
